@@ -10,6 +10,7 @@ class CompanySECResourceSchema(Schema):
 
     id = fields.Integer(dump_only=True)
     cik_str = fields.String(required=True, validate=not_blank)
+    lead = fields.Boolean(allow_none=True)
     ticker = fields.String(allow_none=True)
     title = fields.String(required=True)
     exchange = fields.String(allow_none=True)
@@ -18,6 +19,7 @@ class CompanySECResourceSchema(Schema):
     ir_url = fields.String(allow_none=True)
     is_activated = fields.Boolean(allow_none=True)
     is_biopharma = fields.Boolean(allow_none=True)
+    is_searchable = fields.Boolean(allow_none=True)
     discarded = fields.Boolean(allow_none=True)
     skip_sec = fields.Boolean(allow_none=True)
     last_crawl_date = fields.DateTime(allow_none=True)
@@ -30,8 +32,10 @@ class CompanySECUpdateSchema(Schema):
     company_url = fields.String(allow_none=True)
     pipeline_url = fields.String(allow_none=True)
     ir_url = fields.String(allow_none=True)
+    lead = fields.Boolean(allow_none=True)
     is_activated = fields.Boolean(allow_none=True)
     is_biopharma = fields.Boolean(allow_none=True)
+    is_searchable = fields.Boolean(allow_none=True)
     discarded = fields.Boolean(allow_none=True)
     skip_sec = fields.Boolean(allow_none=True)
     last_crawl_date = fields.DateTime(allow_none=True)
