@@ -29,7 +29,7 @@ class PatentApplicationSubsidiaryModel(Base):
         Float,
         nullable=False,
     )
-    filed_date = Column(DateTime, nullable=True)
+    published_date = Column(DateTime, nullable=True)
     updated_at = Column(
         DateTime,
         nullable=False,
